@@ -1,4 +1,4 @@
-## ---- include = FALSE---------------------------------------------------------
+## ----include = FALSE----------------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>"
@@ -112,7 +112,6 @@ percent=80
 
 #Run the calcPhenotype() function using the parameters you specified above.
 #__________________________________________________________________________________________________________________________________
-original<-getwd()
 wd<-tempdir()
 savedir<-setwd(wd)
 
@@ -137,6 +136,3 @@ calcPhenotype(trainingExprData=trainingExprData,
 #View(pcs[,1,1]) #The first pc. 
 #View(pcs[,1,2]) #The second pc. 
 
-setwd(original)
-
-
